# 
# This file is part of Curses-Toolkit
# 
# This software is copyright (c) 2008 by Damien "dams" Krotkine.
# 
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
# 
use warnings;
use strict;

package Curses::Toolkit::Widget::HScrollBar;
our $VERSION = '0.093000';


# ABSTRACT: a horizontal scrollbar widget

use parent qw{ Curses::Toolkit::Widget };

1;



=pod

=head1 NAME

Curses::Toolkit::Widget::HScrollBar - a horizontal scrollbar widget

=head1 VERSION

version 0.093000

=head1 SYNOPSIS

    # FIXME: not yet implemented

=head1 DESCRIPTION

This widget is a horizontal scrollbar.

=head1 AUTHOR

  Damien "dams" Krotkine

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2008 by Damien "dams" Krotkine.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut 



__END__